;;; DO NOT MODIFY THIS FILE
(if (featurep 'dictionary-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "dictionary/_pkg.el")

(package-provide 'dictionary :version 1.11 :type 'regular)

;;;***

;;;### (autoloads (global-dictionary-tooltip-mode dictionary-tooltip-mode dictionary-popup-matching-words dictionary-mouse-popup-matching-words dictionary-match-words dictionary-lookup-definition dictionary-search dictionary dictionary-mode) "dictionary" "dictionary/dictionary.el")

(autoload 'dictionary-mode "dictionary" "\
This is a mode for searching a dictionary server implementing
 the protocol defined in RFC 2229.

 This is a quick reference to this mode describing the default key bindings:

 * q close the dictionary buffer
 * h display this help information
 * s ask for a new word to search
 * d search the word at point
 * n or Tab place point to the next link
 * p or S-Tab place point to the prev link

 * m ask for a pattern and list all matching words.
 * D select the default dictionary
 * M select the default search strategy

 * Return or Button2 visit that link
 * M-Return or M-Button2 search the word beneath link in all dictionaries
 " nil nil)

(autoload 'dictionary "dictionary" "\
Create a new dictonary buffer and install dictionary-mode" t nil)

(autoload 'dictionary-search "dictionary" "\
Search the `word' in `dictionary' if given or in all if nil.  
It presents the word at point as default input and allows editing it." t nil)

(autoload 'dictionary-lookup-definition "dictionary" "\
Unconditionally lookup the word at point." t nil)

(autoload 'dictionary-match-words "dictionary" "\
Search `pattern' in current default dictionary using default strategy." t nil)

(autoload 'dictionary-mouse-popup-matching-words "dictionary" "\
Display entries matching the word at the cursor" t nil)

(autoload 'dictionary-popup-matching-words "dictionary" "\
Display entries matching the word at the point" t nil)

(autoload 'dictionary-tooltip-mode "dictionary" "\
Display tooltips for the current word" t nil)

(autoload 'global-dictionary-tooltip-mode "dictionary" "\
Enable/disable dictionary-tooltip-mode for all buffers" t nil)

;;;***

(provide 'dictionary-autoloads)
